%% Housekeeping
clear all;
close all
clc;

%%
% In order to match DSGE sector numbers with calibration sector codes (NACE):
NACE = string({'A', 'C_ETS', 'C_NonETS', 'B_D', 'E', 'F', 'G_H_NonETS_I', 'H_ETS', 'J', 'M_N', 'R_S'});
DSGE_sector = [1:size(NACE,2)];


% When solving the model, we take the calibration file as given. This file 
% contains the sectoral parameter values. 
load('Calibration.mat')

% Match DSGE region names with the ones specified in calibration tool:
ISO = {'Reg_a', 'Reg_b', 'Reg_c'}; % Note: EU is reg_A, RoW is Reg_b
DSGE_country = {'a', 'b', 'c'};

% Write and adjust auxiliary files in order to execute the optimization of
% intermediate inputs and capital:
make_getk_text(DSGE_sector,DSGE_country);
make_getk_SS_text(DSGE_sector,DSGE_country);

%% test
simulation = 1;
dynare simul.mod nowarn nostrict;
return

%% Baseline simulations
% 1: Carbon pricing in a 
% 2: Carbon pricing in a and b
% 3: Carbon pricing in a,b and c
% 4: Carbon pricing in a plus border adjustment vis-a-vis b and c
% 5: Carbon pricing in a and b plus border adjustment vis-a-vis c

for i=1:5
    simulation = i;
    dynare simul.mod nowarn nostrict;
    Save_Results; 
end

% Generate figures and tables
cd Results
 
 Fig_prepare;
 Figures_aggregate;
 Figure_sectors;
 Figures_welf;
 Figures_all_scenarios;
 Figures_trade;
 Tables;

cd ..

%% Alternative global carbon pricing scenarios with price discrimination and transfers 

Alternative_Simulations


cd .. 

