%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Targets and parameters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

betta   = 0.985;                                                           // Discount factor                                          
sig     = 1;                                                               // Intertemporal elasticity of substitution
delta	= 0.025;                                                           // Depr. rate
Psi2    = 0.5;

pop_world = Calibration.WPP.pop_a + Calibration.WPP.pop_b + Calibration.WPP.pop_c + Calibration.WPP.pop_d;
@#for co in country
set_param_value('size_@{co}', Calibration.WPP.pop_@{co}/pop_world); // "size" governs the population, world population is normalized to unity!
set_param_value('Y_VA_@{co}_ts', (Calibration.SEA.Reg_@{co}.Value_added(end)/Calibration.WPP.pop_@{co}(end)) ./ (Calibration.SEA.Reg_a.Value_added(end)/Calibration.WPP.pop_a(end))); // Aggregate output per capita of region relative to region A
@#endfor
rer_ba_ts   = 1;                                                           //Real exchange rate between countries a and b
rer_ca_ts   = 1;                                                           //Real exchange rate between countries a and c
rer_cb_ts   = 1;                                                           //Real exchange rate between countries b and c

ner_ba_ts   = 1;                                                           //Real exchange rate between countries a and b
ner_ca_ts   = 1;                                                           //Real exchange rate between countries a and c
ner_cb_ts   = 1;    

@#for co in country
epsi_@{co}_ts = 1;                                                         // Aggregate TFP shock
rho_eps_@{co}   = 0.8;                                                     // Persistence TFP shock
    
lab_@{co}       = 1.4;                                                       // Inverse Frisch elasticity of labor supply

N_@{co}_ts      = 0.333;                                                   // Steady state hours -> 1/3 of time endowmwnt

PI_@{co}_ts = 1;                                                           // Relative price of investment basket (normalized to 1)

R_@{co}_ts  = 1/betta;                                                     // Nominal interest rate <-> real interest rate since gross inflation = 1

TQ_@{co}_ts = 1;
kappaI_@{co} = 25;
tau_I_@{co}_ts = 0;
tau_k_@{co}_ts = 0.214;

rk_@{co}_ts = (R_@{co}_ts-1)/(1-tau_k_@{co}_ts)+delta;                     // Real rental rate of capital

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Climate-related variables/parameters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
rho_EM  = 1-0.9979;                                                        // Rate of decay wrt atmosph. carbon concentration

P_EM_@{co}_ts = 0.0013;                                                   // Initial carbon price level

@#endfor


@#for co in country
Country_Index = ismember(DSGE_country, {'@{co}'}); % In order to match DSGE_country names with ISO country names in calibration

    @#for se in [1:sector]
    Sector_Index = DSGE_sector==@{se};  % In order to match DSGE_sectors with NACE sector names in calibration
    
    // Constant emission per unit of output:
    set_param_value('carb_int_@{se}_@{co}', Calibration.Emissions.Const_frac.(ISO{Country_Index}){NACE(Sector_Index),6});    % Emissions per unit of output, specified using the value of 2005

    % gama1_@{se}_@{co}  = 0;   % Damage function parameter (proportional)
    % gama2_@{se}_@{co}  = 0;   % Damage function parameter (quadratic)
    thetap_@{se}_@{co} = nan; % not used
    kappap_@{se}_@{co} = nan; % not used
    @#endfor

    dam_uti_@{co} = 0; % not used
@#endfor
@#for se in [1:sector]
   
    gama1_@{se}_a  = -6.84266538454707e-05;
    gama1_@{se}_b  = -6.81732017362522e-05;
    gama1_@{se}_c  = -6.48956543751683e-05;
    gama2_@{se}_a  = 4.73294963770035e-07;
    gama2_@{se}_b  = 4.6987974218564e-07;
    gama2_@{se}_c  = 4.69201911947514e-07;
   
   // gama1_@{se}_@{co}       = 0;            % Damage function parameter (proportional)
    //gama2_@{se}_@{co}       = 0;            % Damage function parameter (quadratic)

@#endfor

% Relative sectoral output loss 
@#for se in [1:sector]
 
Pen_@{se}_a_ts = 0.0114;
Pen_@{se}_b_ts = 0.0113;
Pen_@{se}_c_ts = 0.0115;

//Pen_@{se}_@{co}_ts      = 0;    
@#endfor

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Production parameters and elasticities of substitution
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

@#for se in [1:sector]
phi1_@{se}_a = 0.034;
phi1_@{se}_b = 0.036;
phi1_@{se}_c = 0.066;
@#for co in country
phi2_@{se}_@{co} = 2.8;
@#endfor
@#endfor

@#for co in country
Country_Index = ismember(DSGE_country, {'@{co}'}); % In order to match DSGE_country names with ISO country names in calibration

sigc_@{co}  = 1-1/0.9091;                                                   // Determines elasticity of substitution between sector-level consumption goods
sigi_@{co}  = 1-1/0.7511;                                                   // Determines elasticity of substitution between sector-level investment goods

upsi_K_@{co}= 2;                                                            // Determines the elasticity of substitution of capital across sectors, taken from Bouakez et al. (2023) )
upsi_N_@{co}= 2;                                                            // Determines the elasticity of substitution of labor across sectors, taken from Bouakez et al. (2023))


@#for se in [1:sector]
Sector_Index = DSGE_sector==@{se};  % In order to match DSGE_sectors with NACE sector names in calibration

set_param_value('alphaN_@{se}_@{co}', mean(Calibration.SEA.(ISO{Country_Index}).(NACE(Sector_Index)).alpha_N)); // Elasticity of output wrt labor (calibrated to WIOD 2005 data)
set_param_value('alphaH_@{se}_@{co}', mean(Calibration.SEA.(ISO{Country_Index}).(NACE(Sector_Index)).alpha_H)); // Elasticity of output wrt intermediate-goods (calibrated to WIOD 2005 data)

set_param_value('omega_N_@{se}_@{co}', mean(Calibration.SEA.(ISO{Country_Index}).(NACE(Sector_Index)).omega_N)); // Weight attached to labor provided to sector se
set_param_value('omega_K_@{se}_@{co}', mean(Calibration.SEA.(ISO{Country_Index}).(NACE(Sector_Index)).omega_K)); // Weight attached to capital provided to sector se

set_param_value('Psi_con_@{se}_@{co}', Calibration.WIOD.mean.(ISO{Country_Index}).NA.Psi_C_I_G{NACE(Sector_Index), 'Psi_C'});  // Sectoral shares in the consumption good bundle
set_param_value('Psi_inv_@{se}_@{co}', Calibration.WIOD.mean.(ISO{Country_Index}).NA.Psi_C_I_G{NACE(Sector_Index), 'Psi_I'});  // Sectoral shares in the investment good bundle

@#endfor

@#for se in [1:sector]                                                     
set_param_value('kappap_@{se}_@{co}', 75);                                  // Sticky price parameter
@#endfor
         
thetap_1_@{co}= 1.2/(1.2-1);
thetap_2_@{co}= 1.2/(1.2-1);
thetap_3_@{co}= 1.18/(1.18-1);
thetap_4_@{co}= 1.31/(1.31-1);
thetap_5_@{co}= 1.21/(1.21-1);
thetap_6_@{co}= 1.21/(1.21-1);
thetap_7_@{co}= 1.46/(1.46-1);
thetap_8_@{co}= 1.86/(1.86-1);
thetap_9_@{co}= 1.64/(1.64-1);
thetap_10_@{co}= 1.58/(1.58-1);
thetap_11_@{co}= 1.58/(1.58-1);
                                

pi_cpi_@{co}_ts = 1;
@#for se in [1:sector]  
pi_ppi_@{se}_@{co}_ts = 1;
@#endfor
theta=0.8;

@#for se in [1:sector]
UU_@{se}_@{co}_ts = ((P_EM_@{co}_ts*carb_int_@{se}_@{co})/(phi1_@{se}_@{co}*phi2_@{se}_@{co}))^(1/(phi2_@{se}_@{co}-1));
EMC_cost_@{se}_@{co}_ts = phi1_@{se}_@{co}*UU_@{se}_@{co}_ts^(phi2_@{se}_@{co});
EM_cost_@{se}_@{co}_ts = EMC_cost_@{se}_@{co}_ts + P_EM_@{co}_ts*carb_int_@{se}_@{co}*(1-UU_@{se}_@{co}_ts);
//mc_tild_@{se}_@{co}_ts = 1;
mc_tild_@{se}_@{co}_ts = (thetap_@{se}_@{co}-1)/thetap_@{se}_@{co};
//kappa=(1-betta*theta)*(1-theta)/theta;
//kappa=1;
//mc_tild_@{se}_@{co}_ts = (1-betta)/kappa;
mc_@{se}_@{co}_ts = mc_tild_@{se}_@{co}_ts - EM_cost_@{se}_@{co}_ts;
@#for co2 in country
P_@{se}_@{co}_@{co2}_ts = 1;
pi_ppi_@{se}_@{co}_@{co2}_ts = 1; % not used
Aux_@{se}_@{co}_@{co2}_ts = 1;
@#endfor
PH_@{se}_@{co}_ts = 1;
P_@{se}_@{co}_ts = 1; % not used
@#endfor

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Inter-sector trade shares
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

@#for se in [1:sector]                                                     
Sector_Index = DSGE_sector==@{se};  % Match DSGE_sectors with NACE sector names in calibration

@#for se2 in [1:sector]
Sector2_Index = DSGE_sector==@{se2};
set_param_value('Psi_@{se}_@{se2}_@{co}', Calibration.WIOD.mean.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se
@#endfor

%% Substitution elasticities
sigh_@{se}_@{co} = 1-1/0.3;

@#endfor                                 
@#endfor

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Solving for the steady state values
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

kk = getk(M_,DSGE_sector, DSGE_country);
@#include "getk_SS.mod"

@#for co in country

I_@{co}_ts = delta*K_@{co}_ts;
C_@{co}_ts = Y_VA_@{co}_ts - I_@{co}_ts;

@#for se in [1:sector]

C_@{se}_@{co}_ts = Psi_con_@{se}_@{co}*C_@{co}_ts;
I_@{se}_@{co}_ts = Psi_inv_@{se}_@{co}*I_@{co}_ts;


Y_@{se}_@{co}_ts = C_@{se}_@{co}_ts+I_@{se}_@{co}_ts + ( 
@#for se2 in [1:sector]
+H_@{se2}_@{se}_@{co}_ts
@#endfor
);

Y_@{co}_ts = Y_VA_@{co}_ts;

//Y_GO_@{se}_@{co}_ts = Y_@{se}_@{co}_ts;


ZZ_@{se}_@{co}_ts = carb_int_@{se}_@{co}*(1-UU_@{se}_@{co}_ts)*Y_@{se}_@{co}_ts;
Mit_@{se}_@{co}_ts = carb_int_@{se}_@{co}*UU_@{se}_@{co}_ts*Y_@{se}_@{co}_ts;

@#endfor
@#endfor

@#for co in country
ZZ_@{co}_ts = (
@#for se in [1:sector]
+ ZZ_@{se}_@{co}_ts
@#endfor
);
@#endfor

EM_ts = (
@#for co in country 
@#for se in [1:sector]
+ ZZ_@{se}_@{co}_ts*size_@{co}
@#endfor
@#endfor
)/rho_EM;

@#for co in country
@#for se in [1:sector]
   
gama0_@{se}_@{co} =  Pen_@{se}_@{co}_ts - gama1_@{se}_@{co}*EM_ts - gama2_@{se}_@{co}*EM_ts^2;

rk_@{se}_@{co}_ts = (rk_@{co}_ts/(alphaH_@{se}_@{co}*(1-alphaN_@{se}_@{co})*mc_@{se}_@{co}_ts*Y_@{se}_@{co}_ts/K_@{co}_ts/omega_K_@{se}_@{co})^(1-upsi_K_@{co}))^(1/upsi_K_@{co});
K_@{se}_@{co}_ts = omega_K_@{se}_@{co}*(rk_@{co}_ts/rk_@{se}_@{co}_ts)^(1/(1-upsi_K_@{co}))*K_@{co}_ts;

H_@{se}_@{co}_ts = (1-alphaH_@{se}_@{co})*mc_@{se}_@{co}_ts*Y_@{se}_@{co}_ts/PH_@{se}_@{co}_ts;

@#for se2 in [1:sector]
H_@{se}_@{se2}_@{co}_ts = Psi_@{se}_@{se2}_@{co}*(PH_@{se}_@{co}_ts/P_@{se2}_@{co}_@{co}_ts)^(1/(1-sigh_@{se}_@{co}))*H_@{se}_@{co}_ts;
@#endfor

tau_H_@{se}_@{co}_ts = 0;
Y_VA_@{se}_@{co}_ts = (1-EM_cost_@{se}_@{co}_ts)*Y_@{se}_@{co}_ts - H_@{se}_@{co}_ts;

@#endfor

w_@{co}_ts = (
@#for se in [1:sector]
+alphaH_@{se}_@{co}*alphaN_@{se}_@{co}*mc_@{se}_@{co}_ts*Y_@{se}_@{co}_ts/N_@{co}_ts
@#endfor
);

@#for se in [1:sector]
w_@{se}_@{co}_ts = (alphaH_@{se}_@{co}*alphaN_@{se}_@{co}*mc_@{se}_@{co}_ts*Y_@{se}_@{co}_ts/N_@{co}_ts/omega_N_@{se}_@{co}/w_@{co}_ts)^(1-1/upsi_N_@{co})*w_@{co}_ts;
omega_N_tild_@{se}_@{co} = omega_N_@{se}_@{co}*(w_@{co}_ts/w_@{se}_@{co}_ts)^(1/(1-upsi_N_@{co}));
N_@{se}_@{co}_ts = omega_N_tild_@{se}_@{co}*N_@{co}_ts;

epsi_@{se}_@{co}_ts = Y_@{se}_@{co}_ts/( (1-Pen_@{se}_@{co}_ts)* (N_@{se}_@{co}_ts^alphaN_@{se}_@{co}*K_@{se}_@{co}_ts^(1-alphaN_@{se}_@{co}))^alphaH_@{se}_@{co}*H_@{se}_@{co}_ts^(1-alphaH_@{se}_@{co}));


@#endfor

tau_c_@{co}_ts = 0.2;
@#for se in [1:sector]
tau_cc_@{se}_@{co}_ts = tau_c_@{co}_ts;
tau_CCC_@{se}_@{co}_ts = 0;
@#endfor
tau_w_@{co}_ts = 0.4;

gam_ghh_@{co} = 0.001;
X_ghh_@{co}_ts = C_@{co}_ts;

kappaN_@{co} = (betta*(1-gam_ghh_@{co})-1)/N_@{co}_ts^lab_@{co}*lab_@{co}/((betta*(1-gam_ghh_@{co})-1)*lab_@{co}*C_@{co}_ts/N_@{co}_ts/w_@{co}_ts/(1-tau_w_@{co}_ts)*(1+tau_c_@{co}_ts)-gam_ghh_@{co});
lambda_@{co}_ts = (C_@{co}_ts-kappaN_@{co}*N_@{co}_ts^lab_@{co}/lab_@{co}*X_ghh_@{co}_ts)^(-sig)*kappaN_@{co}*N_@{co}_ts^(lab_@{co}-1)*X_ghh_@{co}_ts/(w_@{co}_ts*(1-tau_w_@{co}_ts));
mu_ghh_@{co}_ts = (lambda_@{co}_ts*(1+tau_c_@{co}_ts) - (C_@{co}_ts-kappaN_@{co}*N_@{co}_ts^lab_@{co}/lab_@{co}*X_ghh_@{co}_ts)^(-sig))/gam_ghh_@{co};

@#endfor


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Multi-country part
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


@#for co in country
@#for se in [1:sector]
TB_@{se}_@{co}_ts           = 0;
PC_@{se}_@{co}_ts           = 1;
PI_@{se}_@{co}_ts           = 1;
tau_III_@{se}_@{co}_ts      = 0;
@#for se2 in [1:sector]
PHH_@{se}_@{se2}_@{co}_ts   = 1;
tau_HHH_@{se}_@{se2}_@{co}_ts = 0;
@#endfor

sigc_@{se}_@{co}            = 1-1/0.9;
sigi_@{se}_@{co}            = 1-1/0.9;
sighh_@{se}_@{co}           = 1-1/0.9;


@#endfor
@#endfor

@#for co in country 
TB_@{co}_ts = (
@#for se in [1:sector]
+ TB_@{se}_@{co}_ts
@#endfor
);
NFA_@{co}_ts = TB_@{co}_ts;
@#endfor


@#for co in country
    Country_Index = ismember(DSGE_country, {'@{co}'}); % in order to match DSGE_country names with ISO country names in calibration
    @#for co2 in country
        Country2_Index = ismember(DSGE_country, {'@{co2}'}); % in order to match DSGE_country names with ISO country names in calibration
        @#for se in [1:sector]
            Sector_Index = DSGE_sector==@{se};  % in order to match DSGE_sectors with NACE sector names in calibration
            set_param_value('hb_con_@{se}_@{co}_@{co2}', Calibration.WIOD.mean.(ISO{Country_Index}).NA.Biases_C_I.(ISO{Country2_Index}){NACE(Sector_Index), 'HB_C'}); 
            set_param_value('hb_inv_@{se}_@{co}_@{co2}', Calibration.WIOD.mean.(ISO{Country_Index}).NA.Biases_C_I.(ISO{Country2_Index}){NACE(Sector_Index), 'HB_I'}); 
            @#for se2 in [1:sector]
                Sector2_Index = DSGE_sector==@{se2};  % in order to match DSGE_sectors with NACE sector names in calibration
                set_param_value('hb_hhh_@{se}_@{se2}_@{co}_@{co2}', Calibration.WIOD.mean.(ISO{Country_Index}).IO.Biases_hhh.(ISO{Country2_Index}){NACE(Sector2_Index), NACE(Sector_Index)}); 
            @#endfor
        @#endfor
    @#endfor
@#endfor

@#for co in country
@#for co2 in country
@#for se in [1:sector]
C_@{se}_@{co}_@{co2}_ts = hb_con_@{se}_@{co}_@{co2}*C_@{se}_@{co}_ts;
I_@{se}_@{co}_@{co2}_ts = hb_inv_@{se}_@{co}_@{co2}*I_@{se}_@{co}_ts;
@#for se2 in [1:sector]
H_@{se}_@{se2}_@{co}_@{co2}_ts = hb_hhh_@{se}_@{se2}_@{co}_@{co2}*H_@{se}_@{se2}_@{co}_ts;
@#endfor
tau_hhh_@{se}_@{co}_@{co2}_ts = 0;
tau_ccc_@{se}_@{co}_@{co2}_ts = 0;
tau_iii_@{se}_@{co}_@{co2}_ts = 0;
@#endfor
@#endfor
@#endfor

@#for i in 1:nr-1
@#for j in (i+1):nr
@#for se in [1:sector]
Aux_@{se}_@{country[i]}_@{country[j]}_ts = size_@{country[j]}/size_@{country[i]}*(C_@{se}_@{country[j]}_@{country[i]}_ts+I_@{se}_@{country[j]}_@{country[i]}_ts
@#for se2 in [1:sector]
+H_@{se2}_@{se}_@{country[j]}_@{country[i]}_ts
@#endfor
);
Exp_@{se}_@{country[i]}@{country[j]}_ts = Aux_@{se}_@{country[i]}_@{country[j]}_ts/Y_@{se}_@{country[i]}_ts;
@#endfor
Switch_@{country[i]}@{country[j]} = 0; % not used
@#endfor
@#endfor

ZZ_W_ts = (
@#for co in country 
+ size_@{co}*ZZ_@{co}_ts
@#endfor
);

@#for co in country 
@#for se in [1:sector]
TB_quan_@{se}_@{co}_ts = 
@#for co2 in country
+size_@{co2}/size_@{co}*carb_int_@{se}_@{co}*(1-UU_@{se}_@{co}_ts)*(C_@{se}_@{co2}_@{co}_ts+I_@{se}_@{co2}_@{co}_ts
@#for se2 in [1:sector]
+H_@{se2}_@{se}_@{co2}_@{co}_ts
@#endfor
)
-carb_int_@{se}_@{co2}*(1-UU_@{se}_@{co2}_ts)*(C_@{se}_@{co}_@{co2}_ts+I_@{se}_@{co}_@{co2}_ts
@#for se2 in [1:sector]
+H_@{se2}_@{se}_@{co}_@{co2}_ts
@#endfor
)
@#endfor
;
@#endfor
@#endfor

@#for co in country 
Mit_@{co}_ts = (
@#for se in [1:sector]
+ Mit_@{se}_@{co}_ts
@#endfor
);
TB_quan_@{co}_ts = (
@#for se in [1:sector]
+ TB_quan_@{se}_@{co}_ts
@#endfor
);

Welf_@{co}_ts = log(C_@{co}_ts-kappaN_@{co}*N_@{co}_ts^lab_@{co}/lab_@{co}*X_ghh_@{co}_ts)/(1-betta);
CE_@{co}_ts = 0;
Welf_alt_@{co}_ts = Welf_@{co}_ts;
CU_@{co}_ts = (
@#for se in [1:sector]
+ phi1_@{se}_@{co} * UU_@{se}_@{co}_ts^phi2_@{se}_@{co}*Y_@{se}_@{co}_ts
@#endfor
);

@#endfor

Mit_W_ts = (
@#for co in country 
+ size_@{co}*Mit_@{co}_ts
@#endfor
);


